@@ -256,7 +256,7 @@ class AcademCalendar(Base):
 
 class EducPlan(Base):
     """
-    Модель "Учебный план"
+    Учебный план
     """
     __tablename__ = 'univer_educ_plan'
 
@@ -563,6 +563,9 @@ class MarkType(Base):
     # GPA
     gpa = Column('mark_type_gpa', Float)
 
+    # ???
+    arg = Column('mark_type_arg', Integer)
+
     def __repr__(self):
         return '<MarkType {}>'.format(self)
 
@@ -572,9 +575,8 @@ class MarkType(Base):
 
 class Progress(Base):
     """
-    Модель "Прогресс студента"
+    Прогресс студента
     """
-
     __tablename__ = 'univer_progress'
 
     # Идентификатор
@@ -594,6 +596,9 @@ class Progress(Base):
     subject_id = Column(ForeignKey('univer_subject.subject_id'))
     subject = relationship('Subject')
 
+    # Тип дисциплины
+    subject_type = Column(Integer)
+
     # Наименование дисциплины
     subject_name_ru = Column(String(500))
     subject_name_kz = Column(String(500))
